@@ -237,41 +237,62 @@ impl ModelBuilder {
     /// TODO: what about `Service::renames`?
     ///
     fn resolve_shape_name(&self, shape_name: &ShapeName, is_trait: bool) -> Result<ShapeID, Error> {
+        info!(
+            "resolve_shape_name(shape_name: {:?}, is_trait: {})",
+            &shape_name, is_trait
+        );
         match shape_name {
             ShapeName::Qualified(qualified) => {
+                trace!("qualified ShapeID exists, use as is");
                 // If this is a ShapeID already, then just use it as-is.
                 if !qualified.is_member() {
                     Ok(qualified.clone())
                 } else {
+                    error!("expected a qualified ShapeID");
                     Err(ErrorKind::ShapeIDExpected(qualified.clone()).into())
                 }
             }
             ShapeName::Local(local) => {
+                trace!("Local ShapeName: proceeding with resolution...");
                 let references: Vec<&ShapeName> = self
                     .reference_names()
                     .filter(|shape_name| shape_name.shape_name() == local)
                     .collect();
+                debug!(
+                    "Found {} references to check, references => {:#?}",
+                    references.len(),
+                    &references
+                );
                 match references.len() {
                     1 => {
                         // 1. a `use_statement` has imported a shape with the same name
+                        trace!("SUCCESS: a use statement imports this shape explicitly");
                         Ok(references.first().unwrap().as_qualified().unwrap().clone())
                     }
                     0 => {
                         if self.shapes.contains_key(shape_name) {
                             // 2. a shape is defined in the same namespace as the shape with the same name
+                            trace!(
+                                "SUCCESS: shape found in same namespace as shape with same name"
+                            );
                             Ok(self.default_namespace.make_shape(local.clone()))
                         } else if (!is_trait
                             && defined_prelude_shapes().contains(&*local.to_string()))
                             || (is_trait && defined_prelude_traits().contains(&*local.to_string()))
                         {
                             // 3. a shape is defined in the prelude with the same name
+                            trace!("SUCCESS: shape found in prelude with the same name");
                             Ok(prelude_namespace_id().make_shape(local.clone()))
                         } else {
                             // 4. the shape ID is invalid
+                            error!("shape is invalid because no reference found");
                             Err(ErrorKind::UnknownShape(local.to_string()).into())
                         }
                     }
-                    _ => Err(ErrorKind::AmbiguousShape(local.to_string()).into()),
+                    _ => {
+                        error!("shape resolution failed because more than one reference matches");
+                        Err(ErrorKind::AmbiguousShape(local.to_string()).into())
+                    }
                 }
             }
         }
